import { Component, OnInit, OnDestroy } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet, Router, NavigationEnd } from '@angular/router';
import { Subject, takeUntil, filter } from 'rxjs';
import { AuthService } from './services/auth.service';
import { BottomNavigationComponent } from './components/shared/bottom-navigation/bottom-navigation.component';
// import { NotificationService } from './services/notification.service';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [CommonModule, RouterOutlet, BottomNavigationComponent],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss'
})
export class AppComponent implements OnInit, OnDestroy {
  title = 'FashionCraft';
  isAuthenticated = false;
  shouldShowBottomNav = false;
  private destroy$ = new Subject<void>();

  constructor(
    private authService: AuthService,
    private router: Router
    // private notificationService: NotificationService // 如需使用请取消注释并导入
  ) {}

  ngOnInit(): void {
    // 检查用户登录状态
    this.authService.isAuthenticated$.subscribe(isAuth => {
      this.isAuthenticated = isAuth;
      // 当认证状态改变时，更新底部导航栏显示状态
      this.updateBottomNavVisibility(this.router.url);
    });

    // 监听路由变化，控制底部导航栏显示
    this.router.events
      .pipe(
        filter(event => event instanceof NavigationEnd),
        takeUntil(this.destroy$)
      )
      .subscribe((event) => {
        const navEvent = event as NavigationEnd;
        this.updateBottomNavVisibility(navEvent.urlAfterRedirects);
      });

    // 初始化应用
    this.initializeApp();
    
    // 初始化底部导航栏显示状态
    this.updateBottomNavVisibility(this.router.url);
  }

  ngOnDestroy(): void {
    this.destroy$.next();
    this.destroy$.complete();
  }

  private initializeApp(): void {
    // 检查本地存储的用户信息
    const user = localStorage.getItem('fashioncraft_user');
    if (user) {
      try {
        const userData = JSON.parse(user);
        this.authService.setUser(userData);
      } catch (error) {
        console.error('解析用户数据失败:', error);
        localStorage.removeItem('fashioncraft_user');
      }
    }
  }

  private updateBottomNavVisibility(url: string): void {
    // 在auth页面不显示底部导航栏
    this.shouldShowBottomNav = !url.includes('/auth') && this.isAuthenticated;
  }
} 