import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthService } from '../../services/auth.service';
// @ts-ignore
import { NotificationService } from '../../services/notification.service';

@Component({
  selector: 'app-auth',
  standalone: true,
  imports: [CommonModule, ReactiveFormsModule],
  templateUrl: './auth.component.html',
  styleUrls: ['./auth.component.scss']
})
export class AuthComponent implements OnInit {
  isLoginMode = true;
  loginForm!: FormGroup;
  registerForm!: FormGroup;
  isLoading = false;
  errorMessage = '';

  constructor(
    private fb: FormBuilder,
    private authService: AuthService,
    private router: Router,
    private notificationService: NotificationService
  ) {}

  ngOnInit(): void {
    this.initForms();
  }

  initForms(): void {
    this.loginForm = this.fb.group({
      username: ['', [Validators.required]],
      password: ['', [Validators.required, Validators.minLength(6)]]
    });

    this.registerForm = this.fb.group({
      username: ['', [Validators.required]],
      email: ['', [Validators.required, Validators.email]],
      password: ['', [Validators.required, Validators.minLength(6)]],
      confirmPassword: ['', [Validators.required]]
    }, { validators: this.passwordMatchValidator });
  }

  private passwordMatchValidator(form: FormGroup): { [key: string]: boolean } | null {
    const password = form.get('password');
    const confirmPassword = form.get('confirmPassword');
    
    if (password && confirmPassword && password.value !== confirmPassword.value) {
      return { 'passwordMismatch': true };
    }
    return null;
  }

  switchMode(): void {
    this.isLoginMode = !this.isLoginMode;
  }

  async onSubmit(): Promise<void> {
    if (this.isLoading) return;

    const form = this.isLoginMode ? this.loginForm : this.registerForm;
    if (form.invalid) {
      this.markFormGroupTouched(form);
      return;
    }

    this.isLoading = true;

    try {
      if (this.isLoginMode) {
        await this.authService.login(form.value);
      } else {
        await this.authService.register(form.value);
      }
      
      this.notificationService.showSuccess(
        this.isLoginMode ? '登录成功' : '注册成功',
        '正在跳转到主页...'
      );
      
      this.router.navigate(['/home']);
    } catch (error: any) {
      this.notificationService.showError(
        this.isLoginMode ? '登录失败' : '注册失败',
        error.message || '请稍后重试'
      );
    } finally {
      this.isLoading = false;
    }
  }

  private markFormGroupTouched(formGroup: FormGroup): void {
    Object.keys(formGroup.controls).forEach(key => {
      const control = formGroup.get(key);
      control?.markAsTouched();

      if (control instanceof FormGroup) {
        this.markFormGroupTouched(control);
      }
    });
  }

  getErrorMessage(fieldName: string): string {
    const form = this.isLoginMode ? this.loginForm : this.registerForm;
    const field = form.get(fieldName);
    
    if (field?.errors && field.touched) {
      if (field.errors['required']) {
        return '此字段为必填项';
      }
      if (field.errors['email']) {
        return '请输入有效的邮箱地址';
      }
      if (field.errors['minlength']) {
        return `最少需要${field.errors['minlength'].requiredLength}个字符`;
      }
      if (field.errors['passwordMismatch']) {
        return '两次输入的密码不一致';
      }
    }
    return '';
  }
} 