import { Component, OnInit, OnDestroy } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';
import { Subject } from 'rxjs';
import { AuthService } from '../../services/auth.service';
import { NotificationService } from '../../services/notification.service';
import { CommunityService } from '../../services/community.service';
import { User } from '../../models/user.model';
import { Work } from '../../models/work.model';

@Component({
  selector: 'app-community',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './community.component.html',
  styleUrls: ['./community.component.scss']
})
export class CommunityComponent implements OnInit, OnDestroy {
  private destroy$ = new Subject<void>();
  
  // 用户相关
  currentUser: User | null = null;
  
  // 作品相关
  works: Work[] = [];
  
  // 上传模态框相关
  isUploadModalOpen = false;
  currentUploadStep = 1;
  
  newWork: {
    type: string;
    title: string;
    description: string;
    category: string;
    tags: string[];
    visibility: 'public' | 'followers' | 'private';
    allowDownload: boolean;
    allowComments: boolean;
  } = this.getInitialNewWork();

  uploadedFiles: { file: File, type: string, preview: string }[] = [];
  selectedDesigns: number[] = [];
  popularTags: string[] = ['#时尚', '#原创', '#简约', '#复古', '#街头', '#优雅', '#运动', '#环保'];
  copyrightAgree = false;
  titleCount = 0;
  descCount = 0;

  constructor(
    private router: Router,
    private authService: AuthService,
    private notificationService: NotificationService,
    private communityService: CommunityService
  ) {}
  
  ngOnInit(): void {
    // this.loadWorks(); // Kept for future use if a dynamic grid is added
    this.authService.user$.subscribe(user => {
      this.currentUser = user;
    });
  }
  
  ngOnDestroy(): void {
    this.destroy$.next();
    this.destroy$.complete();
  }

  likeWork(event: MouseEvent): void {
    const target = event.target as HTMLElement;
    target.style.transform = 'scale(0.95)';
    setTimeout(() => {
        target.style.transform = 'scale(1)';
    }, 150);
    this.notificationService.showSuccess('点赞成功', '感谢你的支持！');
  }

  // --- Upload Modal Logic ---

  openUploadModal(): void {
    this.isUploadModalOpen = true;
    this.resetUploadModal();
  }

  closeUploadModal(): void {
    this.isUploadModalOpen = false;
  }

  resetUploadModal(): void {
    this.currentUploadStep = 1;
    this.newWork = this.getInitialNewWork();
    this.uploadedFiles = [];
    this.selectedDesigns = [];
    this.copyrightAgree = false;
    this.updateCharCount('title');
    this.updateCharCount('description');
  }

  getInitialNewWork() {
    return {
      type: '',
      title: '',
      description: '',
      category: '',
      tags: [],
      visibility: 'public' as 'public' | 'followers' | 'private',
      allowDownload: true,
      allowComments: true
    };
  }

  nextUploadStep(): void {
    if (this.validateCurrentStep()) {
      this.currentUploadStep++;
    }
  }

  prevUploadStep(): void {
    if (this.currentUploadStep > 1) {
      this.currentUploadStep--;
    }
  }

  validateCurrentStep(): boolean {
    switch (this.currentUploadStep) {
      case 1:
        if (!this.newWork.type) {
          this.notificationService.showWarning('验证失败', '请选择作品类型');
          return false;
        }
        break;
      case 2:
        if (this.uploadedFiles.length === 0 && this.selectedDesigns.length === 0) {
          this.notificationService.showWarning('验证失败', '请上传内容或选择设计');
          return false;
        }
        break;
      case 3:
        if (!this.newWork.title.trim()) {
          this.notificationService.showWarning('验证失败', '请输入作品标题');
          return false;
        }
        break;
      case 4:
        if (!this.copyrightAgree) {
          this.notificationService.showWarning('验证失败', '请同意版权声明');
          return false;
        }
        break;
    }
    return true;
  }

  selectWorkType(type: string): void {
    this.newWork.type = type;
  }

  handleFileUpload(event: Event): void {
    const input = event.target as HTMLInputElement;
    if (input.files) {
      const files = Array.from(input.files);
      for (const file of files) {
        if (this.uploadedFiles.length >= 9) {
          this.notificationService.showWarning('上传限制', '最多只能上传9个文件');
          break;
        }
        const reader = new FileReader();
        reader.onload = (e: any) => {
          this.uploadedFiles.push({ file, type: file.type, preview: e.target.result });
        };
        reader.readAsDataURL(file);
      }
    }
  }

  handle3DUpload(event: Event): void {
    const input = event.target as HTMLInputElement;
    if (input.files && input.files[0]) {
      this.notificationService.showSuccess('3D文件上传成功', input.files[0].name);
    }
  }

  removeFile(index: number): void {
    this.uploadedFiles.splice(index, 1);
  }

  selectFromMyDesigns(designId: number): void {
    if (this.isSelectedDesign(designId)) {
      this.selectedDesigns = this.selectedDesigns.filter(id => id !== designId);
    } else {
      this.selectedDesigns.push(designId);
    }
  }
  
  isSelectedDesign(designId: number): boolean {
    return this.selectedDesigns.includes(designId);
  }

  toggleTag(tag: string): void {
    if (this.isTagSelected(tag)) {
      this.newWork.tags = this.newWork.tags.filter(t => t !== tag);
    } else {
      this.newWork.tags.push(tag);
    }
  }
  
  isTagSelected(tag: string): boolean {
    return this.newWork.tags.includes(tag);
  }

  addCustomTag(event: KeyboardEvent): void {
    const input = event.target as HTMLInputElement;
    if (event.key === 'Enter' && input.value.trim()) {
      event.preventDefault();
      const tag = `#${input.value.trim()}`;
      if (!this.isTagSelected(tag)) {
        this.newWork.tags.push(tag);
      }
      input.value = '';
    }
  }

  updateCharCount(field: 'title' | 'description'): void {
    if (field === 'title') {
      this.titleCount = this.newWork.title.length;
    } else {
      this.descCount = this.newWork.description.length;
    }
  }

  publishWork(): void {
    if (!this.validateCurrentStep()) {
      return;
    }
    
    // In a real app, you would use a service to send this data to a backend.
    console.log('Publishing work:', this.newWork);
    console.log('Uploaded files:', this.uploadedFiles);
    console.log('Selected designs:', this.selectedDesigns);

    this.notificationService.showSuccess('发布成功', '您的作品已成功发布！');
    this.closeUploadModal();
  }
} 