import { Component, OnInit, OnDestroy } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router } from '@angular/router';
import { NotificationService } from '../../services/notification.service';

interface ColorScheme {
  id: string;
  name: string;
  colors: string[];
  description?: string;
}

interface AIScheme {
  name: string;
  description: string;
  colors: string[];
}

@Component({
  selector: 'app-design-center',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './design-center.component.html',
  styleUrls: ['./design-center.component.scss']
})
export class DesignCenterComponent implements OnInit, OnDestroy {
  // 状态管理
  currentSelectedPart = 'overall';
  currentPartName = '整体';
  currentPartColor = '#3498db';
  selectedColor = '蓝色';
  customColor = '#ff6b6b';
  showHistory = false;
  showAIModal = false;
  showZonePanel = true;
  
  // 旋转状态
  modelRotation = 0;
  
  // 可用颜色列表
  availableColors = [
    // 原有7种颜色
    '蓝色', '粉色', '牛油果绿', '白色', '黑色', '橘色', '利灰',
    // 新增14种颜色
    '宝蓝色', '浅驼色', '测试色', '深灰绿', '深紫色', '深绿色',
    '真朱', '睿智金', '红色', '萌萌绿', '蒂芙尼蓝', '长春花蓝',
    '青紫', '靓丽黄'
  ];
  
  // 颜色配色方案
  colorSchemes: ColorScheme[] = [
    {
      id: 'scheme1',
      name: '夏日活力',
      colors: ['#ff6b6b', '#4ecdc4', '#ffeaa7']
    },
    {
      id: 'scheme2',
      name: '深海紫韵',
      colors: ['#667eea', '#764ba2', '#a29bfe']
    }
  ];
  
  // AI推荐方案
  aiSchemes: AIScheme[] = [
    {
      name: '商务精英',
      description: '专业稳重，适合商务场合',
      colors: ['#2c3e50', '#34495e', '#7f8c8d']
    },
    {
      name: '春日暖阳',
      description: '温暖明亮，充满活力',
      colors: ['#ffeaa7', '#fab1a0', '#fd79a8']
    },
    {
      name: '海洋清新',
      description: '清新自然，如海风般舒适',
      colors: ['#0891b2', '#3b82f6', '#06b6d4']
    }
  ];
  
  // 部位名称映射
  partNames: { [key: string]: string } = {
    'overall': '整体',
    's1': 'S1部位',
    't1': 'T1部位',
    'y1': 'Y1部位',
    'z1': 'Z1部位'
  };
  
  // 颜色十六进制映射
  colorHexMap: { [key: string]: string } = {
    '蓝色': '#3498db',
    '粉色': '#e91e63',
    '牛油果绿': '#8bc34a',
    '白色': '#ffffff',
    '黑色': '#2c3e50',
    '橘色': '#ff9800',
    '利灰': '#9e9e9e',
    '宝蓝色': '#1e40af',
    '浅驼色': '#d2b48c',
    '测试色': '#9ca3af',
    '深灰绿': '#374151',
    '深紫色': '#581c87',
    '深绿色': '#14532d',
    '真朱': '#dc2626',
    '睿智金': '#fbbf24',
    '红色': '#ef4444',
    '萌萌绿': '#84cc16',
    '蒂芙尼蓝': '#0891b2',
    '长春花蓝': '#3b82f6',
    '青紫': '#6b46c1',
    '靓丽黄': '#eab308'
  };
  
  // 各部位当前颜色
  partColors: { [key: string]: string } = {
    's1': '蓝色',
    't1': '蓝色',
    'y1': '蓝色',
    'z1': '蓝色'
  };

  constructor(
    private router: Router,
    private notificationService: NotificationService
  ) {}

  ngOnInit() {
    this.initializeDesignCenter();
    this.loadSavedDesign();
  }

  ngOnDestroy() {
    // 清理工作
  }

  // 初始化设计中心
  initializeDesignCenter() {
    console.log('初始化3D设计中心');
    this.updateCurrentPartInfo();
  }

  // 加载保存的设计
  loadSavedDesign() {
    const savedDesign = localStorage.getItem('designCenter_currentDesign');
    if (savedDesign) {
      try {
        const design = JSON.parse(savedDesign);
        this.partColors = design.partColors || this.partColors;
        this.currentSelectedPart = design.currentSelectedPart || 'overall';
        this.updateCurrentPartInfo();
      } catch (error) {
        console.error('加载保存的设计失败:', error);
      }
    }
  }

  // 保存当前设计
  saveCurrentDesign() {
    const designData = {
      partColors: this.partColors,
      currentSelectedPart: this.currentSelectedPart,
      timestamp: new Date().toISOString()
    };
    
    localStorage.setItem('designCenter_currentDesign', JSON.stringify(designData));
  }

  // 选择服装颜色 - 主要的颜色切换功能
  selectClothingColor(colorName: string) {
    console.log('选择颜色:', colorName, '当前部位:', this.currentSelectedPart);
    
    if (this.currentSelectedPart === 'overall') {
      // 整体颜色切换 - 所有部位
      this.updateAllParts(colorName);
    } else {
      // 单独部位颜色切换
      this.updateSinglePart(this.currentSelectedPart, colorName);
    }
    
    this.selectedColor = colorName;
    this.updateColorSwatchState(colorName);
    this.updateCurrentPartInfo();
    this.saveCurrentDesign();
    
    this.showNotification('颜色切换', `已切换到${colorName}`);
  }

  // 更新所有部位颜色
  updateAllParts(colorName: string) {
    const parts = ['s1', 't1', 'y1', 'z1'];
    parts.forEach(part => {
      this.updatePartImage(part, colorName);
      this.partColors[part] = colorName;
    });
  }

  // 更新单个部位颜色
  updateSinglePart(partName: string, colorName: string) {
    this.updatePartImage(partName, colorName);
    if (partName in this.partColors) {
      this.partColors[partName] = colorName;
    }
  }

  // 更新部位图片 - 核心图片切换逻辑
  updatePartImage(partName: string, colorName: string) {
    const imgElement = document.querySelector(`#layer-${partName} img`) as HTMLImageElement;
    if (imgElement) {
      const imagePath = this.getImagePath(partName, colorName);
      imgElement.src = imagePath;
      console.log('更新图片:', partName, '→', imagePath);
    }
  }

  // 获取图片路径 - 关键的路径处理逻辑
  getImagePath(partName: string, colorName: string): string {
    const partMap: { [key: string]: string } = {
      's1': 'S1.png',
      't1': 'T1.png',
      'y1': 'Y1.png',
      'z1': 'Z1.png'
    };
    
    const filename = partMap[partName];
    if (!filename) return '';
    
    // 检查是否在新切片图中
    const extendedColors = [
      '宝蓝色', '浅驼色', '测试色', '深灰绿', '深紫色', '深绿色',
      '真朱', '睿智金', '红色', '萌萌绿', '蒂芙尼蓝', '长春花蓝',
      '青紫', '靓丽黄'
    ];
    
    if (extendedColors.includes(colorName)) {
      if (colorName === '浅驼色') {
        const lowercaseFilename = filename.toLowerCase();
        return `切片图/切片图/${colorName}/${lowercaseFilename}`;
      }
      return `切片图/切片图/${colorName}/${filename}`;
    }
    
    // 原有颜色
    const oldColors = ['蓝色', '粉色', '牛油果绿', '白色', '黑色', '橘色', '利灰'];
    if (oldColors.includes(colorName)) {
      // 特殊处理：橘色和利灰只有T1和Y1
      if ((colorName === '橘色' || colorName === '利灰') && (partName === 's1' || partName === 'z1')) {
        // 如果橘色或利灰没有该部位，使用蓝色替代
        return `切片图共7个/切片图共7个/蓝色/${filename}`;
      }
      return `切片图共7个/切片图共7个/${colorName}/${filename}`;
    }
    
    // 默认返回蓝色作为备用
    return `切片图共7个/切片图共7个/蓝色/${filename}`;
  }

  // 选择身体部位
  selectBodyPart(partName: string) {
    console.log('选择部位:', partName);
    this.currentSelectedPart = partName;
    
    // 更新按钮状态
    this.updatePartTabState(partName);
    
    // 更新当前部位信息
    this.updateCurrentPartInfo();
    
    // 高亮显示选中部位
    this.highlightSelectedPart(partName);
    
    this.showNotification('部位选择', `已选择${this.partNames[partName]}`);
  }

  // 更新部位选择器状态
  updatePartTabState(partName: string) {
    const tabs = document.querySelectorAll('.part-tab');
    tabs.forEach(tab => {
      tab.classList.remove('active');
    });
    
    const selectedTab = document.querySelector(`[data-part="${partName}"]`);
    if (selectedTab) {
      selectedTab.classList.add('active');
    }
  }

  // 高亮显示选中部位
  highlightSelectedPart(partName: string) {
    // 清除所有高亮
    const images = document.querySelectorAll('.part-image');
    images.forEach(img => {
      img.classList.remove('highlighted', 'selected');
    });
    
    // 高亮选中部位
    if (partName !== 'overall') {
      const selectedImg = document.querySelector(`#layer-${partName} img`);
      if (selectedImg) {
        selectedImg.classList.add('selected');
      }
    }
  }

  // 更新当前部位信息
  updateCurrentPartInfo() {
    this.currentPartName = this.partNames[this.currentSelectedPart] || this.currentSelectedPart;
    
    if (this.currentSelectedPart === 'overall') {
      // 整体模式，显示主要颜色
      this.currentPartColor = this.colorHexMap[this.selectedColor] || '#3498db';
    } else {
      // 单个部位模式
      const partColor = this.partColors[this.currentSelectedPart];
      this.currentPartColor = this.colorHexMap[partColor] || '#3498db';
    }
  }

  // 更新颜色选择器状态
  updateColorSwatchState(colorName: string) {
    const swatches = document.querySelectorAll('.color-swatch');
    swatches.forEach(swatch => {
      swatch.classList.remove('active');
      if (swatch.getAttribute('data-color') === colorName) {
        swatch.classList.add('active');
      }
    });
  }

  // 3D模型控制
  rotateModel(direction: string) {
    const rotationAmount = 90;
    
    if (direction === 'left') {
      this.modelRotation -= rotationAmount;
    } else if (direction === 'right') {
      this.modelRotation += rotationAmount;
    }
    
    const model = document.getElementById('main3DModel');
    if (model) {
      model.style.transform = `rotateY(${this.modelRotation}deg)`;
    }
    
    this.showNotification('视角调整', `模型已${direction === 'left' ? '向左' : '向右'}旋转`);
  }

  // 重置模型视角
  resetModelView() {
    this.modelRotation = 0;
    const model = document.getElementById('main3DModel');
    if (model) {
      model.style.transform = 'rotateY(0deg)';
    }
    
    this.showNotification('视角重置', '模型视角已重置');
  }

  // 切换区域控制面板
  toggleZonePanel() {
    this.showZonePanel = !this.showZonePanel;
    this.showNotification('面板控制', `区域控制面板已${this.showZonePanel ? '展开' : '收起'}`);
  }

  // 同步颜色到所有部位
  syncColorToAll() {
    const currentColor = this.currentSelectedPart === 'overall' 
      ? this.selectedColor 
      : this.partColors[this.currentSelectedPart];
    
    this.updateAllParts(currentColor);
    this.selectedColor = currentColor;
    this.updateColorSwatchState(currentColor);
    this.updateCurrentPartInfo();
    this.saveCurrentDesign();
    
    this.showNotification('颜色同步', `已将${currentColor}同步到所有部位`);
  }

  // 显示配色历史
  showColorHistory() {
    this.showHistory = !this.showHistory;
    this.showNotification('配色历史', this.showHistory ? '已显示配色历史' : '已隐藏配色历史');
  }

  // 保存配色方案
  saveColorScheme() {
    const schemeData = {
      name: `方案-${new Date().toLocaleString()}`,
      colors: Object.values(this.partColors),
      timestamp: new Date().toISOString()
    };
    
    // 保存到本地存储
    const savedSchemes = JSON.parse(localStorage.getItem('designCenter_colorSchemes') || '[]');
    savedSchemes.push(schemeData);
    localStorage.setItem('designCenter_colorSchemes', JSON.stringify(savedSchemes));
    
    this.showNotification('方案保存', '配色方案已保存');
  }

  // 加载配色方案
  loadColorScheme(schemeId: string) {
    const scheme = this.colorSchemes.find(s => s.id === schemeId);
    if (scheme) {
      // 应用预设方案
      const colors = scheme.colors;
      const parts = ['s1', 't1', 'y1', 'z1'];
      
      parts.forEach((part, index) => {
        if (colors[index]) {
          // 这里需要将十六进制颜色转换为颜色名称
          const colorName = this.findColorNameByHex(colors[index]);
          if (colorName) {
            this.updatePartImage(part, colorName);
            this.partColors[part] = colorName;
          }
        }
      });
      
      this.updateCurrentPartInfo();
      this.saveCurrentDesign();
      this.showNotification('方案加载', `已加载${scheme.name}方案`);
    }
  }

  // 根据十六进制颜色查找颜色名称
  findColorNameByHex(hex: string): string | null {
    for (const [name, color] of Object.entries(this.colorHexMap)) {
      if (color.toLowerCase() === hex.toLowerCase()) {
        return name;
      }
    }
    return null;
  }

  // 选择自定义颜色
  selectCustomColor(event: Event) {
    const target = event.target as HTMLInputElement;
    this.customColor = target.value;
    
    // 这里可以实现自定义颜色的应用逻辑
    this.showNotification('自定义颜色', `已选择自定义颜色: ${this.customColor}`);
  }

  // 添加自定义颜色到色盘
  addCustomColor() {
    // 实现添加自定义颜色到色盘的逻辑
    this.showNotification('自定义色盘', '自定义颜色已添加到色盘');
  }

  // 高级工具函数
  openAdvancedEmbroidery() {
    this.showNotification('刺绣编辑器', '刺绣编辑器功能开发中...');
  }

  openTextureSystem() {
    this.showNotification('贴图系统', '贴图系统功能开发中...');
  }

  openPatternLibrary() {
    this.showNotification('图案库', '图案库功能开发中...');
  }

  openAIDesigner() {
    this.showAIModal = true;
  }

  // AI模态框控制
  closeAIModal(event?: Event) {
    if (event) {
      event.preventDefault();
      event.stopPropagation();
    }
    this.showAIModal = false;
  }

  // 应用AI推荐方案
  applyAIScheme(scheme: AIScheme) {
    const parts = ['s1', 't1', 'y1', 'z1'];
    
    parts.forEach((part, index) => {
      if (scheme.colors[index]) {
        const colorName = this.findColorNameByHex(scheme.colors[index]);
        if (colorName) {
          this.updatePartImage(part, colorName);
          this.partColors[part] = colorName;
        }
      }
    });
    
    this.updateCurrentPartInfo();
    this.saveCurrentDesign();
    this.closeAIModal();
    
    this.showNotification('AI推荐', `已应用${scheme.name}方案`);
  }

  // 获取颜色的十六进制值
  getColorHex(colorName: string): string {
    return this.colorHexMap[colorName] || '#3498db';
  }

  // 显示通知
  private showNotification(title: string, message: string) {
    console.log(`[${title}] ${message}`);
    // 使用通知服务显示通知
    if (this.notificationService) {
      // 临时使用console.log，等待通知服务完善
      console.log(`通知: ${message}`);
    }
  }

  // 重置设计
  resetDesign() {
    // 重置所有部位为默认颜色
    this.partColors = {
      's1': '蓝色',
      't1': '蓝色',
      'y1': '蓝色',
      'z1': '蓝色'
    };
    
    // 重置选中部位
    this.currentSelectedPart = 'overall';
    this.selectedColor = '蓝色';
    
    // 重置模型旋转
    this.modelRotation = 0;
    
    // 更新UI
    this.updateAllParts('蓝色');
    this.updateColorSwatchState('蓝色');
    this.updateCurrentPartInfo();
    this.resetModelView();
    
    // 更新部位选择器状态
    this.updatePartTabState('overall');
    
    this.showNotification('设计重置', '设计已重置为默认状态');
  }

  // 导出设计
  exportDesign() {
    const designData = {
      partColors: this.partColors,
      timestamp: new Date().toISOString(),
      version: '1.0'
    };
    
    const dataStr = JSON.stringify(designData, null, 2);
    const dataUri = 'data:application/json;charset=utf-8,'+ encodeURIComponent(dataStr);
    
    const exportFileDefaultName = `design_${new Date().toISOString().split('T')[0]}.json`;
    
    const linkElement = document.createElement('a');
    linkElement.setAttribute('href', dataUri);
    linkElement.setAttribute('download', exportFileDefaultName);
    linkElement.click();
    
    this.showNotification('导出成功', '设计文件已导出');
  }

  // 分享设计
  shareDesign() {
    const shareData = {
      title: '我的服装设计',
      text: '看看我在FashionCraft中创建的服装设计！',
      url: window.location.href
    };
    
    if (navigator.share) {
      navigator.share(shareData);
    } else {
      // 复制链接到剪贴板
      navigator.clipboard.writeText(window.location.href);
      this.showNotification('分享链接', '链接已复制到剪贴板');
    }
  }
} 