import { Component, OnInit, OnDestroy, ViewChild, ElementRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';
import { Subject, takeUntil } from 'rxjs';
import { NotificationService } from '../../services/notification.service';


@Component({
  selector: 'app-fitting-room',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './fitting-room.component.html',
  styleUrls: ['./fitting-room.component.scss']
})
export class FittingRoomComponent implements OnInit, OnDestroy {
  private destroy$ = new Subject<void>();

  // 流程控制
  currentFittingStep: string = 'upload';
  uploadMethod: string = 'camera';
  clothingTab: string = 'my-designs';

  // 试衣数据
  selectedClothing: string | null = null;
  userPhoto: string | null = null;
  
  // 交互控制
  currentRotation: number = 0;
  currentLighting: string = 'natural';
  compareMode: string = 'split';


  constructor(
    private router: Router,
    private notificationService: NotificationService,
  ) {}

  ngOnInit(): void {
    this.initializeFittingRoom();
  }

  ngOnDestroy(): void {
    this.destroy$.next();
    this.destroy$.complete();
  }

  setStep(stepName: string): void {
    if (!stepName) {
        console.error('setStep: stepName is required');
        return;
    }
    this.currentFittingStep = stepName;
    this.notificationService.showInfo('流程进度', `已进入${this.getStepTitle(stepName)}阶段`);
  }

  getStepTitle(stepName: string): string {
      const titles: { [key: string]: string } = {
          'upload': '照片上传',
          'clothing': '服装选择',
          'fitting': '试衣展示'
      };
      return titles[stepName] || stepName;
  }

  selectUploadMethod(method: string): void {
      this.uploadMethod = method;
      this.notificationService.showInfo('上传方式', `已选择${method === 'camera' ? '拍照模式' : '相册选择'}`);
  }

  startCamera(): void {
      this.notificationService.showInfo('启动摄像头', '正在访问摄像头权限...');
      setTimeout(() => {
          this.notificationService.showSuccess('摄像头就绪', '可以开始拍摄了！');
      }, 1500);
  }

  capturePhoto(): void {
      this.notificationService.showInfo('拍摄照片', '正在拍摄...');
      setTimeout(() => {
          const poseCalibrationElement = document.getElementById('pose-calibration');
          if(poseCalibrationElement) poseCalibrationElement.style.display = 'block';
          this.simulatePoseDetection();
          this.notificationService.showSuccess('拍摄成功', '正在进行姿势校准...');
      }, 1000);
  }

  switchCamera(): void {
      this.notificationService.showInfo('切换摄像头', '已切换到前置/后置摄像头');
  }

  handlePhotoUpload(event: Event): void {
    const input = event.target as HTMLInputElement;
    if (input.files && input.files[0]) {
      const file = input.files[0];
      const reader = new FileReader();
      reader.onload = (e: any) => {
          this.userPhoto = e.target.result;
          const cropAreaElement = document.getElementById('crop-area');
          if(cropAreaElement) cropAreaElement.style.display = 'block';
          this.notificationService.showInfo('照片上传', '请调整裁剪区域');
      };
      reader.readAsDataURL(file);
    }
  }

  resetCrop(): void {
      this.notificationService.showInfo('重置裁剪', '已重置到原始尺寸');
  }

  confirmCrop(): void {
    const poseCalibrationElement = document.getElementById('pose-calibration');
    if(poseCalibrationElement) poseCalibrationElement.style.display = 'block';
    this.simulatePoseDetection();
    this.notificationService.showInfo('裁剪完成', '正在进行姿势校准...');
  }

  simulatePoseDetection(): void {
      const statuses = document.querySelectorAll('.status-item');
      let currentIndex = 2; // 从身形分析开始

      const updateStatus = () => {
          if (currentIndex < statuses.length) {
              const item = statuses[currentIndex];
              const icon = item.querySelector('.status-icon');
              if(icon) icon.textContent = '✅';
              currentIndex++;

              if (currentIndex < statuses.length) {
                  setTimeout(updateStatus, 1000);
              } else {
                  this.notificationService.showSuccess('校准完成', '人体姿势识别成功！');
              }
          }
      };

      setTimeout(updateStatus, 1000);
  }

  recalibrate(): void {
      const statuses = document.querySelectorAll('.status-item');
      statuses.forEach((item, index) => {
          const icon = item.querySelector('.status-icon');
          if (index >= 2 && icon) {
              icon.textContent = '⏳';
          }
      });

      this.simulatePoseDetection();
      this.notificationService.showInfo('重新校准', '正在重新分析姿势...');
  }

  switchClothingTab(tabName: string): void {
      this.clothingTab = tabName;
      const tabNames: { [key: string]: string } = {
          'my-designs': '我的设计',
          'community': '社区热门',
          'brands': '品牌合作'
      };
      this.notificationService.showInfo('切换分类', `已切换到${tabNames[tabName]}`);
  }

  selectClothing(clothingId: string): void {
      this.selectedClothing = clothingId;
      
      const allItems = document.querySelectorAll('.design-item, .trending-item, .brand-item');
      allItems.forEach(item => {
        item.classList.remove('selected');
      });
      // This is not ideal as it relies on DOM query. A better approach would be to manage state in the component.
      // For now, I'll keep it to match the original logic.
      const el = document.querySelector(`[onclick="selectClothing('${clothingId}')"]`);
      if(el) {
        el.classList.add('selected');
      }

      this.notificationService.showSuccess('选择服装', '已选择该款设计，可以进行试穿了！');
  }

  rotateFitting(direction: 'left' | 'right' | 'reset'): void {
      if (direction === 'left') {
          this.currentRotation -= 30;
      } else if (direction === 'right') {
          this.currentRotation += 30;
      } else {
          this.currentRotation = 0;
      }

      const viewport = document.querySelector('.fitting-viewport') as HTMLElement;
      if (viewport) {
          viewport.style.transform = `rotateY(${this.currentRotation}deg)`;
      }

      this.notificationService.showInfo('旋转视角', `视角：${this.currentRotation}°`);
  }

  setFittingLight(lightType: string): void {
      this.currentLighting = lightType;

      const lightFilters: { [key: string]: string } = {
          'natural': 'brightness(1.1) contrast(1.05)',
          'indoor': 'brightness(0.9) sepia(0.1)',
          'studio': 'brightness(1.2) contrast(1.1) saturate(1.1)'
      };

      const viewport = document.querySelector('.fitting-viewport') as HTMLElement;
      if (viewport) {
          viewport.style.filter = lightFilters[lightType];
      }

      const lightNames: { [key: string]: string } = {
          'natural': '自然光',
          'indoor': '室内光',
          'studio': '摄影光'
      };

      this.notificationService.showInfo('光照调节', `已切换到${lightNames[lightType]}`);
  }

  toggleCompare(mode: string): void {
      this.compareMode = mode;

      const modeNames: { [key: string]: string } = {
          'split': '左右对比',
          'overlay': '叠加对比'
      };

      this.notificationService.showInfo('对比模式', `已切换到${modeNames[mode]}`);
  }

  retryFitting(): void {
      this.notificationService.showInfo('重新试穿', '正在重新进行智能贴合...');
      setTimeout(() => {
          this.notificationService.showSuccess('试穿完成', '新的试穿效果已生成！');
      }, 2000);
  }

  saveImageCard(): void {
      this.notificationService.showInfo('保存形象卡', '正在生成专属形象卡...');
      setTimeout(() => {
          this.notificationService.showSuccess('保存成功', '形象卡已保存到相册！');
      }, 1500);
  }

  shareToCommunity(): void {
      this.notificationService.showInfo('分享到社区', '正在上传到设计社区...');
      setTimeout(() => {
          this.notificationService.showSuccess('分享成功', '已分享到社区，快去看看大家的反应吧！');
      }, 2000);
  }

  buyNow(): void {
      if (!this.selectedClothing) {
          this.notificationService.showError('购买提醒', '请先选择要购买的服装');
          return;
      }
      this.notificationService.showInfo('跳转购买', '正在跳转到购买页面...');
      setTimeout(() => {
          this.notificationService.showSuccess('购买页面', '已为您打开购买链接！');
      }, 1000);
  }

  initializeFittingRoom(): void {
      console.log('3D试衣间已初始化');
  }
} 