import { Component, AfterViewChecked, ElementRef, ViewChild, OnInit } from '@angular/core';
import { CommonModule, DatePipe } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';

// A global-like function for notifications, can be replaced by a proper service
declare function showNotification(title: string, message: string): void;

export interface ChatMessage {
  sender: 'user' | 'ai';
  text: string;
  htmlText: string;
  timestamp: Date;
  isFormatted?: boolean;
}

@Component({
  selector: 'app-ai-chat',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './ai-chat.component.html',
  styleUrls: ['./ai-chat.component.scss'],
  providers: [DatePipe]
})
export class AiChatComponent implements OnInit, AfterViewChecked {
  @ViewChild('aiChatMessages') private messagesContainer!: ElementRef;

  messages: ChatMessage[] = [];
  newMessage = '';
  isLoading = false;
  aiChatSubtitle = '智能搭配助手在线中...';
  
  constructor(private router: Router) {}

  ngOnInit(): void {
    this.addMessage(
      'ai',
      '**你好！我是由DeepSeek AI驱动的专属时尚顾问** ✨<br><br>' +
      '我可以帮您：<br>' +
      '• **服装搭配** - 根据场合推荐最佳组合<br>' +
      '• **配色建议** - 打造和谐视觉效果<br>' +
      '• **风格分析** - 找到最适合您的穿衣风格<br><br>' +
      '> 💡 想聊什么时尚话题呢？我会为您提供专业的建议！',
      true
    );
  }

  ngAfterViewChecked(): void {
    this.scrollToBottom();
  }

  private scrollToBottom(): void {
    try {
      this.messagesContainer.nativeElement.scrollTop = this.messagesContainer.nativeElement.scrollHeight;
    } catch (err) { }
  }

  closeChat(): void {
    this.router.navigate(['/home']);
  }

  addMessage(sender: 'user' | 'ai', text: string, isFormatted = false): void {
    this.messages.push({
      sender,
      text,
      htmlText: isFormatted ? this.formatAIText(text) : text,
      timestamp: new Date(),
      isFormatted
    });
  }

  sendMessage(): void {
    const messageText = this.newMessage.trim();
    if (messageText === '') return;

    this.addMessage('user', messageText);
    this.newMessage = '';
    this.isLoading = true;

    // Simulate AI response
    setTimeout(() => {
      this.isLoading = false;
      const aiResponse = this.generateAIResponse(messageText);
      this.addMessage('ai', aiResponse, true);
    }, 1500 + Math.random() * 1000);
  }

  sendQuickCommand(command: string): void {
    this.addMessage('user', command);
    this.isLoading = true;

    // Simulate AI response
    setTimeout(() => {
      this.isLoading = false;
      const aiResponse = this.generateAIResponse(command);
      this.addMessage('ai', aiResponse, true);
    }, 1000);
  }
  
  startVoiceInput() {
    // This would require a speech recognition library
    showNotification('语音输入', '此功能正在开发中！');
  }

  uploadImage() {
    // This would require file upload handling
    showNotification('图片识别', '此功能正在开发中！');
  }

  showEmoji() {
    this.newMessage += '😊';
  }

  private generateAIResponse(userMessage: string): string {
    const responses: { [key: string]: string[] } = {
        '商务': [
            '**商务装搭配建议** 👔<br><br>为了打造专业且不失时尚感的形象，我建议：<br>1. **核心单品**: 一件合身的深蓝色 (如 #1E3A8A) 或炭灰色西装外套。 <br>2. **内搭**: 简约的白色丝质衬衫或高领针织衫。<br>3. **下装**: 同色系西裤或一条剪裁利落的阔腿裤。<br><br>> 💡 **提示**: 利用配饰如精致的手表或一条有质感的皮带可以提升整体造型的品味。'
        ],
        '春季': [
            '**春季流行色搭配** 🌸<br><br>今年春天，柔和且充满活力的颜色是主流：<br>• **樱花粉**: 温柔浪漫，适合打造甜美造型。<br>• **薄荷绿**: 清新自然，带来一丝凉意。<br>• **奶油黄**: 温暖明亮，充满阳光气息。<br><br>[建议] 您可以尝试将这些颜色作为主色调，搭配白色或米色等中性色，效果会非常好！'
        ],
        '约会': [
            '**浪漫约会穿搭** 💕<br><br>为您推荐一套既优雅又不会过于隆重的约会装扮：<br>- **连衣裙**: 一条印花真丝连衣裙，展现女性魅力。👗<br>- **外套**: 如果天气微凉，可以外搭一件米色风衣或针织开衫。<br>- **鞋履**: 选择一双舒适的中跟鞋或优雅的平底鞋。👠<br><br>> ✨ **小巧思**: 一条精致的项链或一对耳环会是完美的点睛之笔。'
        ]
    };

    for (const keyword in responses) {
        if (userMessage.includes(keyword)) {
            const possibleResponses = responses[keyword];
            return possibleResponses[Math.floor(Math.random() * possibleResponses.length)];
        }
    }
    return '这是一个很有趣的想法！<br><br>为了给您更精准的建议，可以告诉我更多细节吗？比如：<br>- 您要参加的 **场合** 是什么？<br>- 您偏爱哪种 **风格**？（例如：简约、复-古、街头等）<br>- 您有喜欢的 **颜色** 吗？';
  }

  private formatAIText(text: string): string {
    let formattedText = text;
    // Basic formatting, can be expanded
    formattedText = formattedText.replace(/\*\*(.*?)\*\*/g, '<strong class="ai-bold">$1</strong>');
    formattedText = formattedText.replace(/\*(.*?)\*/g, '<em class="ai-italic">$1</em>');
    // ... add more formatting rules from app.html if needed
    formattedText = formattedText.replace(/✨/g, '<span class="ai-sparkle">✨</span>');
    formattedText = formattedText.replace(/💡/g, '<span class="ai-idea">💡</span>');
    formattedText = formattedText.replace(/🎨/g, '<span class="ai-art">🎨</span>');
    formattedText = formattedText.replace(/👔/g, '<span class="ai-suit">👔</span>');
    formattedText = formattedText.replace(/👗/g, '<span class="ai-dress">👗</span>');
    formattedText = formattedText.replace(/👠/g, '<span class="ai-heels">👠</span>');
    formattedText = formattedText.replace(/💄/g, '<span class="ai-makeup">💄</span>');
    formattedText = formattedText.replace(/👜/g, '<span class="ai-bag">👜</span>');
    formattedText = formattedText.replace(/\[重要\]/g, '<span class="ai-tag ai-tag-important">重要</span>');
    formattedText = formattedText.replace(/\[建议\]/g, '<span class="ai-tag ai-tag-suggestion">建议</span>');
    formattedText = formattedText.replace(/\[提示\]/g, '<span class="ai-tag ai-tag-tip">提示</span>');
    formattedText = formattedText.replace(/^>\s(.+)$/gm, '<div class="ai-quote"><span class="ai-quote-icon">💡</span> $1</div>');
    return formattedText;
  }
} 