import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';

export interface Notification {
  id: string;
  type: 'success' | 'error' | 'warning' | 'info';
  title: string;
  message: string;
  duration?: number;
  actions?: NotificationAction[];
}

export interface NotificationAction {
  label: string;
  action: () => void;
}

@Injectable({
  providedIn: 'root'
})
export class NotificationService {
  private notificationSubject = new Subject<Notification>();
  public notifications$ = this.notificationSubject.asObservable();

  constructor() {}

  showSuccess(title: string, message: string, duration = 3000): void {
    this.show('success', title, message, duration);
  }

  showError(title: string, message: string, duration = 5000): void {
    this.show('error', title, message, duration);
  }

  showWarning(title: string, message: string, duration = 4000): void {
    this.show('warning', title, message, duration);
  }

  showInfo(title: string, message: string, duration = 3000): void {
    this.show('info', title, message, duration);
  }

  showWithActions(type: Notification['type'], title: string, message: string, actions: NotificationAction[], duration = 0): void {
    this.show(type, title, message, duration, actions);
  }

  private show(type: Notification['type'], title: string, message: string, duration = 3000, actions?: NotificationAction[]): void {
    const notification: Notification = {
      id: this.generateId(),
      type,
      title,
      message,
      duration,
      actions
    };

    this.notificationSubject.next(notification);

    // 创建并显示通知DOM元素
    this.createNotificationElement(notification);
  }

  private createNotificationElement(notification: Notification): void {
    const notificationElement = document.createElement('div');
    notificationElement.className = `notification notification-${notification.type}`;
    notificationElement.style.cssText = `
      position: fixed;
      top: 20px;
      left: 50%;
      transform: translateX(-50%);
      background: ${this.getBackgroundColor(notification.type)};
      color: white;
      padding: 15px 20px;
      border-radius: 25px;
      box-shadow: 0 10px 30px rgba(0,0,0,0.3);
      z-index: 10000;
      max-width: 300px;
      text-align: center;
      animation: slideDown 0.3s ease;
    `;

    notificationElement.innerHTML = `
      <div style="font-weight: 600; margin-bottom: 5px;">${notification.title}</div>
      <div style="font-size: 14px; opacity: 0.9;">${notification.message}</div>
    `;

    // 添加动画样式
    const style = document.createElement('style');
    style.textContent = `
      @keyframes slideDown {
        from { transform: translateX(-50%) translateY(-100%); opacity: 0; }
        to { transform: translateX(-50%) translateY(0); opacity: 1; }
      }
    `;
    document.head.appendChild(style);

    document.body.appendChild(notificationElement);

    // 自动移除通知
    if (notification.duration && notification.duration > 0) {
      setTimeout(() => {
        this.removeNotificationElement(notificationElement);
      }, notification.duration);
    }
  }

  private removeNotificationElement(element: HTMLElement): void {
    element.style.animation = 'slideDown 0.3s ease reverse';
    setTimeout(() => {
      if (element.parentNode) {
        element.parentNode.removeChild(element);
      }
    }, 300);
  }

  private getBackgroundColor(type: Notification['type']): string {
    switch (type) {
      case 'success':
        return 'linear-gradient(45deg, #4ade80, #22c55e)';
      case 'error':
        return 'linear-gradient(45deg, #ef4444, #dc2626)';
      case 'warning':
        return 'linear-gradient(45deg, #f59e0b, #d97706)';
      case 'info':
        return 'linear-gradient(45deg, #3b82f6, #2563eb)';
      default:
        return 'linear-gradient(45deg, #ff6b6b, #ffa726)';
    }
  }

  private generateId(): string {
    return Date.now().toString(36) + Math.random().toString(36).substr(2);
  }
} 